_session_endpoints = [
    [
        'login',
        '/api/2.0/fo/session/?action=login',
        [
            {
                'param_name': 'username',
                'is_required': True
            },
            {
                'param_name': 'password',
                'is_required': True
            },
            
        ]

    ]
]